Notas del codigo:

SAM-NREL no corre con python3. Se tendra que modifcar el codigo para poder correrlo
Todos los codigos se escribiran en python3

This version of the code include a good version of sscapi. For simplicity is located where it is used to avoid the import problem